# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/identity_provider.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/identity_provider.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgateway/identity_provider.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb4\x03\n\x10IdentityProvider\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x0b\xe2\x41\x01\x02\xbaH\x04r\x02\x18?\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12*\n\x0bsaml_config\x18\x05 \x01(\x0b\x32\x13.gateway.SamlConfigH\x00\x12*\n\x0boidc_config\x18\x06 \x01(\x0b\x32\x13.gateway.OidcConfigH\x00:\x96\x01\xea\x41\x85\x01\n!api.fireworks.ai/IdentityProvider\x12;accounts/{AccountId}/identityProviders/{IdentityProviderId}*\x11identityProviders2\x10identityProvider\x82\xf1\x04\t\n\x07\x41\x63\x63ountB\x08\n\x06\x63onfig\"(\n\nSamlConfig\x12\x1a\n\x0cmetadata_url\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\\\n\nOidcConfig\x12\x18\n\nissuer_url\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tclient_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1b\n\rclient_secret\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"q\n\x1d\x43reateIdentityProviderRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12:\n\x11identity_provider\x18\x02 \x01(\x0b\x32\x19.gateway.IdentityProviderB\x04\xe2\x41\x01\x02\"0\n\x1aGetIdentityProviderRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"}\n\x1cListIdentityProvidersRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\"\x83\x01\n\x1dListIdentityProvidersResponse\x12\x35\n\x12identity_providers\x18\x01 \x03(\x0b\x32\x19.gateway.IdentityProvider\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x92\x01\n\x1dUpdateIdentityProviderRequest\x12:\n\x11identity_provider\x18\x01 \x01(\x0b\x32\x19.gateway.IdentityProviderB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"3\n\x1d\x44\x65leteIdentityProviderRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.identity_provider_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_IDENTITYPROVIDER'].fields_by_name['name']._loaded_options = None
  _globals['_IDENTITYPROVIDER'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_IDENTITYPROVIDER'].fields_by_name['display_name']._loaded_options = None
  _globals['_IDENTITYPROVIDER'].fields_by_name['display_name']._serialized_options = b'\342A\001\002\272H\004r\002\030?'
  _globals['_IDENTITYPROVIDER'].fields_by_name['create_time']._loaded_options = None
  _globals['_IDENTITYPROVIDER'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_IDENTITYPROVIDER'].fields_by_name['update_time']._loaded_options = None
  _globals['_IDENTITYPROVIDER'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_IDENTITYPROVIDER']._loaded_options = None
  _globals['_IDENTITYPROVIDER']._serialized_options = b'\352A\205\001\n!api.fireworks.ai/IdentityProvider\022;accounts/{AccountId}/identityProviders/{IdentityProviderId}*\021identityProviders2\020identityProvider\202\361\004\t\n\007Account'
  _globals['_SAMLCONFIG'].fields_by_name['metadata_url']._loaded_options = None
  _globals['_SAMLCONFIG'].fields_by_name['metadata_url']._serialized_options = b'\342A\001\002'
  _globals['_OIDCCONFIG'].fields_by_name['issuer_url']._loaded_options = None
  _globals['_OIDCCONFIG'].fields_by_name['issuer_url']._serialized_options = b'\342A\001\002'
  _globals['_OIDCCONFIG'].fields_by_name['client_id']._loaded_options = None
  _globals['_OIDCCONFIG'].fields_by_name['client_id']._serialized_options = b'\342A\001\002'
  _globals['_OIDCCONFIG'].fields_by_name['client_secret']._loaded_options = None
  _globals['_OIDCCONFIG'].fields_by_name['client_secret']._serialized_options = b'\342A\001\002'
  _globals['_CREATEIDENTITYPROVIDERREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEIDENTITYPROVIDERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEIDENTITYPROVIDERREQUEST'].fields_by_name['identity_provider']._loaded_options = None
  _globals['_CREATEIDENTITYPROVIDERREQUEST'].fields_by_name['identity_provider']._serialized_options = b'\342A\001\002'
  _globals['_GETIDENTITYPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETIDENTITYPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEIDENTITYPROVIDERREQUEST'].fields_by_name['identity_provider']._loaded_options = None
  _globals['_UPDATEIDENTITYPROVIDERREQUEST'].fields_by_name['identity_provider']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEIDENTITYPROVIDERREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEIDENTITYPROVIDERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEIDENTITYPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEIDENTITYPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_IDENTITYPROVIDER']._serialized_start=224
  _globals['_IDENTITYPROVIDER']._serialized_end=660
  _globals['_SAMLCONFIG']._serialized_start=662
  _globals['_SAMLCONFIG']._serialized_end=702
  _globals['_OIDCCONFIG']._serialized_start=704
  _globals['_OIDCCONFIG']._serialized_end=796
  _globals['_CREATEIDENTITYPROVIDERREQUEST']._serialized_start=798
  _globals['_CREATEIDENTITYPROVIDERREQUEST']._serialized_end=911
  _globals['_GETIDENTITYPROVIDERREQUEST']._serialized_start=913
  _globals['_GETIDENTITYPROVIDERREQUEST']._serialized_end=961
  _globals['_LISTIDENTITYPROVIDERSREQUEST']._serialized_start=963
  _globals['_LISTIDENTITYPROVIDERSREQUEST']._serialized_end=1088
  _globals['_LISTIDENTITYPROVIDERSRESPONSE']._serialized_start=1091
  _globals['_LISTIDENTITYPROVIDERSRESPONSE']._serialized_end=1222
  _globals['_UPDATEIDENTITYPROVIDERREQUEST']._serialized_start=1225
  _globals['_UPDATEIDENTITYPROVIDERREQUEST']._serialized_end=1371
  _globals['_DELETEIDENTITYPROVIDERREQUEST']._serialized_start=1373
  _globals['_DELETEIDENTITYPROVIDERREQUEST']._serialized_end=1424
# @@protoc_insertion_point(module_scope)



import time
from fireworks.gateway import Gateway
from fireworks.control_plane.generated.protos_grpcio.gateway.evaluation_job_pb2 import (
    EvaluationJob as SyncEvaluationJob,
    CreateEvaluationJobRequest as SyncCreateEvaluationJobRequest,
)
from fireworks.control_plane.generated.protos_grpcio.gateway.status_pb2 import (
    JobState as SyncJobState,
)
from fireworks._logger import logger


class EvaluationJob:
    def __init__(self, gateway: Gateway, evaluation_job: SyncEvaluationJob):
        self.gateway = gateway
        self.evaluation_job: SyncEvaluationJob = evaluation_job

    def wait_for_completion(self) -> "EvaluationJob":
        logger.info(
            f"Starting to wait for evaluation job {self.evaluation_job.name} to complete. Current state: {self.evaluation_job.state}"
        )

        while self.evaluation_job.state != SyncJobState.JOB_STATE_COMPLETED:
            if self.evaluation_job.state == SyncJobState.JOB_STATE_FAILED:
                logger.error(f"Evaluation job {self.evaluation_job.name} failed")
                raise Exception(f"Evaluation job {self.evaluation_job.name} failed")
            if self.evaluation_job.state == SyncJobState.JOB_STATE_FAILED_CLEANING_UP:
                logger.error(f"Evaluation job {self.evaluation_job.name} failed to clean up")
                raise Exception(f"Evaluation job {self.evaluation_job.name} failed to clean up")
            if self.evaluation_job.state == SyncJobState.JOB_STATE_CANCELLED:
                logger.warning(f"Evaluation job {self.evaluation_job.name} was cancelled")
                raise Exception(f"Evaluation job {self.evaluation_job.name} was cancelled")
            if self.evaluation_job.state == SyncJobState.JOB_STATE_DELETING:
                logger.warning(f"Evaluation job {self.evaluation_job.name} is being deleted")
                raise Exception(f"Evaluation job {self.evaluation_job.name} is being deleted")
            if self.evaluation_job.state == SyncJobState.JOB_STATE_DELETING_CLEANING_UP:
                logger.warning(f"Evaluation job {self.evaluation_job.name} is being deleted during cleanup")
                raise Exception(f"Evaluation job {self.evaluation_job.name} is being deleted")

            logger.debug(
                f"Evaluation job {self.evaluation_job.name} status update - Current state: {SyncJobState.Name(self.evaluation_job.state)}"
            )
            time.sleep(10)
            try:
                self.evaluation_job = (
                    self.gateway.get_evaluation_job_sync(name=self.evaluation_job.name) or self.evaluation_job
                )
            except Exception as e:
                logger.error(f"Failed to get evaluation job status: {e}")
                # Keep existing evaluation job state if update fails
                pass

        logger.info(f"Evaluation job {self.evaluation_job.name} completed successfully")
        return self

    @property
    def output_dataset(self):
        from fireworks.dataset.dataset import Dataset

        if self.evaluation_job.output_dataset:
            return Dataset.from_id(self.evaluation_job.output_dataset.split("/")[-1])
        else:
            raise ValueError(
                "No output dataset found. Is this job completed? ",
                "Make sure to run `sync` and `wait_for_completion` before calling this method.",
            )

    @property
    def id(self):
        if not self.evaluation_job.name:
            raise ValueError("Evaluation job has no name. Make sure to run `sync` before calling this method.")
        return self.evaluation_job.name.split("/")[-1]

    @property
    def name(self):
        if not self.evaluation_job.name:
            raise ValueError("Evaluation job has no name. Make sure to run `sync` before calling this method.")
        return self.evaluation_job.name

    @property
    def url(self):
        return f"https://app.fireworks.ai/dashboard/evaluation-jobs/{self.id}"

    def sync(self):
        """
        Creates the evaluation job if it doesn't exist, otherwise returns the existing job.
        If previous job failed, deletes it and creates a new one.
        """
        try:
            existing_job = self.gateway.get_evaluation_job_sync(name=self.evaluation_job.name)
            if existing_job is not None:
                if (
                    existing_job.state == SyncJobState.JOB_STATE_FAILED
                    or existing_job.state == SyncJobState.JOB_STATE_FAILED_CLEANING_UP
                    or existing_job.state == SyncJobState.JOB_STATE_CANCELLED
                    or existing_job.state == SyncJobState.JOB_STATE_DELETING
                    or existing_job.state == SyncJobState.JOB_STATE_DELETING_CLEANING_UP
                ):
                    logger.debug(f"Deleting existing evaluation job {existing_job.name} in state {existing_job.state}")
                    # Delete the failed job (implementation would depend on available gateway method)
                    # For now, we'll proceed to create a new one
                else:
                    # Update our internal state with the existing job
                    self.evaluation_job = existing_job
                    logger.debug(
                        f"Using existing evaluation job {self.evaluation_job.name} with state: {self.evaluation_job.state}"
                    )
                    return self
        except Exception as e:
            logger.debug(f"Could not get evaluation job {self.evaluation_job.name}: {e}")

        # Create new evaluation job
        request = self._create_request()
        logger.debug(f"Creating new evaluation job {self.evaluation_job.name}")
        new_job = self.gateway.create_evaluation_job_sync(request)
        self.evaluation_job = new_job
        logger.debug(f"Created evaluation job {self.evaluation_job.name} with state: {self.evaluation_job.state}")
        return self

    def _create_request(self) -> SyncCreateEvaluationJobRequest:
        """Create the request object for creating an evaluation job."""
        return SyncCreateEvaluationJobRequest(
            evaluation_job=self.evaluation_job,
        )



from ..buf.validate import validate_pb2 as _validate_pb2
from . import deployment_pb2 as _deployment_pb2
from . import options_pb2 as _options_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WorkloadShape(_message.Message):
    __slots__ = ("name", "display_name", "description", "create_time", "update_time", "created_by", "annotations", "base_model", "accelerator_count", "accelerator_type", "precision", "world_size", "generator_count", "disaggregated_prefill_count", "disaggregated_prefill_world_size", "max_batch_size", "enable_addons", "draft_token_count", "draft_model", "ngram_speculation_length", "max_lora_batch_size", "kv_cache_memory_pct", "enable_session_affinity", "image_tag", "num_lora_device_cached", "extra_args", "max_context_length", "extra_values", "engine")
    class AnnotationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class ExtraValuesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_COUNT_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    WORLD_SIZE_FIELD_NUMBER: _ClassVar[int]
    GENERATOR_COUNT_FIELD_NUMBER: _ClassVar[int]
    DISAGGREGATED_PREFILL_COUNT_FIELD_NUMBER: _ClassVar[int]
    DISAGGREGATED_PREFILL_WORLD_SIZE_FIELD_NUMBER: _ClassVar[int]
    MAX_BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    ENABLE_ADDONS_FIELD_NUMBER: _ClassVar[int]
    DRAFT_TOKEN_COUNT_FIELD_NUMBER: _ClassVar[int]
    DRAFT_MODEL_FIELD_NUMBER: _ClassVar[int]
    NGRAM_SPECULATION_LENGTH_FIELD_NUMBER: _ClassVar[int]
    MAX_LORA_BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    KV_CACHE_MEMORY_PCT_FIELD_NUMBER: _ClassVar[int]
    ENABLE_SESSION_AFFINITY_FIELD_NUMBER: _ClassVar[int]
    IMAGE_TAG_FIELD_NUMBER: _ClassVar[int]
    NUM_LORA_DEVICE_CACHED_FIELD_NUMBER: _ClassVar[int]
    EXTRA_ARGS_FIELD_NUMBER: _ClassVar[int]
    MAX_CONTEXT_LENGTH_FIELD_NUMBER: _ClassVar[int]
    EXTRA_VALUES_FIELD_NUMBER: _ClassVar[int]
    ENGINE_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    description: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    created_by: str
    annotations: _containers.ScalarMap[str, str]
    base_model: str
    accelerator_count: int
    accelerator_type: _deployment_pb2.AcceleratorType
    precision: _deployment_pb2.Deployment.Precision
    world_size: int
    generator_count: int
    disaggregated_prefill_count: int
    disaggregated_prefill_world_size: int
    max_batch_size: int
    enable_addons: bool
    draft_token_count: int
    draft_model: str
    ngram_speculation_length: int
    max_lora_batch_size: int
    kv_cache_memory_pct: int
    enable_session_affinity: bool
    image_tag: str
    num_lora_device_cached: int
    extra_args: _containers.RepeatedScalarFieldContainer[str]
    max_context_length: int
    extra_values: _containers.ScalarMap[str, str]
    engine: _deployment_pb2.Deployment.Engine
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., annotations: _Optional[_Mapping[str, str]] = ..., base_model: _Optional[str] = ..., accelerator_count: _Optional[int] = ..., accelerator_type: _Optional[_Union[_deployment_pb2.AcceleratorType, str]] = ..., precision: _Optional[_Union[_deployment_pb2.Deployment.Precision, str]] = ..., world_size: _Optional[int] = ..., generator_count: _Optional[int] = ..., disaggregated_prefill_count: _Optional[int] = ..., disaggregated_prefill_world_size: _Optional[int] = ..., max_batch_size: _Optional[int] = ..., enable_addons: bool = ..., draft_token_count: _Optional[int] = ..., draft_model: _Optional[str] = ..., ngram_speculation_length: _Optional[int] = ..., max_lora_batch_size: _Optional[int] = ..., kv_cache_memory_pct: _Optional[int] = ..., enable_session_affinity: bool = ..., image_tag: _Optional[str] = ..., num_lora_device_cached: _Optional[int] = ..., extra_args: _Optional[_Iterable[str]] = ..., max_context_length: _Optional[int] = ..., extra_values: _Optional[_Mapping[str, str]] = ..., engine: _Optional[_Union[_deployment_pb2.Deployment.Engine, str]] = ...) -> None: ...

class CreateWorkloadShapeRequest(_message.Message):
    __slots__ = ("parent", "workload_shape", "workload_shape_id", "disable_size_validation")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    WORKLOAD_SHAPE_FIELD_NUMBER: _ClassVar[int]
    WORKLOAD_SHAPE_ID_FIELD_NUMBER: _ClassVar[int]
    DISABLE_SIZE_VALIDATION_FIELD_NUMBER: _ClassVar[int]
    parent: str
    workload_shape: WorkloadShape
    workload_shape_id: str
    disable_size_validation: bool
    def __init__(self, parent: _Optional[str] = ..., workload_shape: _Optional[_Union[WorkloadShape, _Mapping]] = ..., workload_shape_id: _Optional[str] = ..., disable_size_validation: bool = ...) -> None: ...

class GetWorkloadShapeRequest(_message.Message):
    __slots__ = ("name", "read_mask")
    NAME_FIELD_NUMBER: _ClassVar[int]
    READ_MASK_FIELD_NUMBER: _ClassVar[int]
    name: str
    read_mask: _field_mask_pb2.FieldMask
    def __init__(self, name: _Optional[str] = ..., read_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class ListWorkloadShapesRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by", "read_mask")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    READ_MASK_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    read_mask: _field_mask_pb2.FieldMask
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ..., read_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class ListWorkloadShapesResponse(_message.Message):
    __slots__ = ("workload_shapes", "next_page_token", "total_size")
    WORKLOAD_SHAPES_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    workload_shapes: _containers.RepeatedCompositeFieldContainer[WorkloadShape]
    next_page_token: str
    total_size: int
    def __init__(self, workload_shapes: _Optional[_Iterable[_Union[WorkloadShape, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateWorkloadShapeRequest(_message.Message):
    __slots__ = ("workload_shape", "update_mask", "disable_size_validation")
    WORKLOAD_SHAPE_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    DISABLE_SIZE_VALIDATION_FIELD_NUMBER: _ClassVar[int]
    workload_shape: WorkloadShape
    update_mask: _field_mask_pb2.FieldMask
    disable_size_validation: bool
    def __init__(self, workload_shape: _Optional[_Union[WorkloadShape, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ..., disable_size_validation: bool = ...) -> None: ...

class DeleteWorkloadShapeRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



# Configure logger with a consistent format for better debugging
import logging
import os
import time
import functools
import inspect
import sys

logging.getLogger("httpx").setLevel(logging.WARNING)

logger = logging.getLogger(__name__)
handler = logging.StreamHandler(sys.stdout)  # Explicitly use stdout instead of stderr
formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
handler.setFormatter(formatter)
logger.addHandler(handler)
logger.propagate = False  # Prevent duplicate logs

if os.environ.get("FIREWORKS_SDK_DEBUG"):
    logger.setLevel(logging.DEBUG)


def log_execution_time(func):
    @functools.wraps(func)
    async def async_wrapper(*args, **kwargs):
        start_time = time.perf_counter()
        result = await func(*args, **kwargs)
        end_time = time.perf_counter()
        execution_time = end_time - start_time
        logger.debug(f"Function {func.__name__} took {execution_time:.4f} seconds to execute")
        return result

    @functools.wraps(func)
    def sync_wrapper(*args, **kwargs):
        start_time = time.perf_counter()
        result = func(*args, **kwargs)
        end_time = time.perf_counter()
        execution_time = end_time - start_time
        logger.debug(f"Function {func.__name__} took {execution_time:.4f} seconds to execute")
        return result

    if inspect.iscoroutinefunction(func):
        return async_wrapper
    return sync_wrapper



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class JobProgress(_message.Message):
    __slots__ = ("percent", "epoch", "chunk", "total_input_requests", "total_processed_requests", "successfully_processed_requests", "failed_requests", "output_rows", "input_tokens", "output_tokens")
    PERCENT_FIELD_NUMBER: _ClassVar[int]
    EPOCH_FIELD_NUMBER: _ClassVar[int]
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    TOTAL_INPUT_REQUESTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_PROCESSED_REQUESTS_FIELD_NUMBER: _ClassVar[int]
    SUCCESSFULLY_PROCESSED_REQUESTS_FIELD_NUMBER: _ClassVar[int]
    FAILED_REQUESTS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_ROWS_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    percent: int
    epoch: int
    chunk: int
    total_input_requests: int
    total_processed_requests: int
    successfully_processed_requests: int
    failed_requests: int
    output_rows: int
    input_tokens: int
    output_tokens: int
    def __init__(self, percent: _Optional[int] = ..., epoch: _Optional[int] = ..., chunk: _Optional[int] = ..., total_input_requests: _Optional[int] = ..., total_processed_requests: _Optional[int] = ..., successfully_processed_requests: _Optional[int] = ..., failed_requests: _Optional[int] = ..., output_rows: _Optional[int] = ..., input_tokens: _Optional[int] = ..., output_tokens: _Optional[int] = ...) -> None: ...



from . import batch_inference_job_pb2 as _batch_inference_job_pb2
from . import job_progress_pb2 as _job_progress_pb2
from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from . import training_pb2 as _training_pb2
from . import wandb_pb2 as _wandb_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReinforcementFineTuningJob(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "completed_time", "dataset", "evaluation_dataset", "eval_auto_carveout", "state", "status", "created_by", "training_config", "evaluator", "wandb_config", "output_stats", "job_progress", "inference_parameters", "chunk_size", "output_stats_internal", "output_metrics")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_TIME_FIELD_NUMBER: _ClassVar[int]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_DATASET_FIELD_NUMBER: _ClassVar[int]
    EVAL_AUTO_CARVEOUT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    TRAINING_CONFIG_FIELD_NUMBER: _ClassVar[int]
    EVALUATOR_FIELD_NUMBER: _ClassVar[int]
    WANDB_CONFIG_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_STATS_FIELD_NUMBER: _ClassVar[int]
    JOB_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    INFERENCE_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    CHUNK_SIZE_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_STATS_INTERNAL_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_METRICS_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    completed_time: _timestamp_pb2.Timestamp
    dataset: str
    evaluation_dataset: str
    eval_auto_carveout: bool
    state: _status_pb2.JobState
    status: _status_pb2.Status
    created_by: str
    training_config: _training_pb2.BaseTrainingConfig
    evaluator: str
    wandb_config: _wandb_pb2.WandbConfig
    output_stats: str
    job_progress: _job_progress_pb2.JobProgress
    inference_parameters: _batch_inference_job_pb2.InferenceParameters
    chunk_size: int
    output_stats_internal: str
    output_metrics: str
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., dataset: _Optional[str] = ..., evaluation_dataset: _Optional[str] = ..., eval_auto_carveout: bool = ..., state: _Optional[_Union[_status_pb2.JobState, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., created_by: _Optional[str] = ..., training_config: _Optional[_Union[_training_pb2.BaseTrainingConfig, _Mapping]] = ..., evaluator: _Optional[str] = ..., wandb_config: _Optional[_Union[_wandb_pb2.WandbConfig, _Mapping]] = ..., output_stats: _Optional[str] = ..., job_progress: _Optional[_Union[_job_progress_pb2.JobProgress, _Mapping]] = ..., inference_parameters: _Optional[_Union[_batch_inference_job_pb2.InferenceParameters, _Mapping]] = ..., chunk_size: _Optional[int] = ..., output_stats_internal: _Optional[str] = ..., output_metrics: _Optional[str] = ...) -> None: ...

class GetReinforcementFineTuningJobRequest(_message.Message):
    __slots__ = ("name", "read_mask")
    NAME_FIELD_NUMBER: _ClassVar[int]
    READ_MASK_FIELD_NUMBER: _ClassVar[int]
    name: str
    read_mask: _field_mask_pb2.FieldMask
    def __init__(self, name: _Optional[str] = ..., read_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class CreateReinforcementFineTuningJobRequest(_message.Message):
    __slots__ = ("parent", "reinforcement_fine_tuning_job", "debug", "reinforcement_fine_tuning_job_id", "skip_validations")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    REINFORCEMENT_FINE_TUNING_JOB_FIELD_NUMBER: _ClassVar[int]
    DEBUG_FIELD_NUMBER: _ClassVar[int]
    REINFORCEMENT_FINE_TUNING_JOB_ID_FIELD_NUMBER: _ClassVar[int]
    SKIP_VALIDATIONS_FIELD_NUMBER: _ClassVar[int]
    parent: str
    reinforcement_fine_tuning_job: ReinforcementFineTuningJob
    debug: bool
    reinforcement_fine_tuning_job_id: str
    skip_validations: bool
    def __init__(self, parent: _Optional[str] = ..., reinforcement_fine_tuning_job: _Optional[_Union[ReinforcementFineTuningJob, _Mapping]] = ..., debug: bool = ..., reinforcement_fine_tuning_job_id: _Optional[str] = ..., skip_validations: bool = ...) -> None: ...

class ListReinforcementFineTuningJobsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by", "read_mask")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    READ_MASK_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    read_mask: _field_mask_pb2.FieldMask
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ..., read_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class ListReinforcementFineTuningJobsResponse(_message.Message):
    __slots__ = ("reinforcement_fine_tuning_jobs", "next_page_token", "total_size")
    REINFORCEMENT_FINE_TUNING_JOBS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    reinforcement_fine_tuning_jobs: _containers.RepeatedCompositeFieldContainer[ReinforcementFineTuningJob]
    next_page_token: str
    total_size: int
    def __init__(self, reinforcement_fine_tuning_jobs: _Optional[_Iterable[_Union[ReinforcementFineTuningJob, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeleteReinforcementFineTuningJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ResumeReinforcementFineTuningJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DebugReinforcementFineTuningJobRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DebugReinforcementFineTuningJobResponse(_message.Message):
    __slots__ = ("name", "failed_job_name")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FAILED_JOB_NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    failed_job_name: str
    def __init__(self, name: _Optional[str] = ..., failed_job_name: _Optional[str] = ...) -> None: ...



from .llm import LLM
from .dataset import Dataset
from .evaluator import Evaluator
from .supervised_fine_tuning_job import SupervisedFineTuningJob
from .batch_inference_job import BatchInferenceJob
import importlib.metadata
from reward_kit import reward_function
from openai.types.chat.chat_completion import ChatCompletion
from openai.types.chat.chat_completion_chunk import ChatCompletionChunk
from openai.types.chat.chat_completion_message_param import ChatCompletionMessageParam
from openai.types.chat.chat_completion_tool_param import ChatCompletionToolParam
from .platform import FireworksPlatform
import fireworks.control_plane.generated.protos.gateway as fw

try:
    __version__ = importlib.metadata.version("fireworks-ai")
except importlib.metadata.PackageNotFoundError:
    __version__ = "0.0.0"  # Fallback for development mode

__all__ = [
    "LLM",
    "Dataset",
    "Evaluator",
    "SupervisedFineTuningJob",
    "BatchInferenceJob",
    "FireworksPlatform",
    "fw",
    "__version__",
    "reward_function",
    "ChatCompletion",
    "ChatCompletionChunk",
    "ChatCompletionMessageParam",
    "ChatCompletionToolParam",
]
